@@ -5,11 +5,12 @@ module Debian.Debianize.InputDebian
     ( inputDebianization
     , inputDebianizationFile
     , inputChangeLog
+    , loadChangeLog
     , dataDest
     , dataTop
     ) where
 
-
+import Debug.Trace
 import Control.Lens
 import Control.Monad (filterM)
 import Control.Monad.State (put)
@@ -17,11 +18,11 @@ import Control.Monad.Trans (liftIO, MonadIO)
 import Data.Char (isSpace)
 import Data.Map as Map (insert, insertWith)
 import Data.Maybe (fromMaybe)
-import Data.Monoid ((<>), mappend)
+import Data.Monoid ((<>))
 import Data.Set as Set (fromList, insert, singleton)
 import Data.Text (break, lines, null, pack, strip, Text, unpack, words)
 import Data.Text.IO (readFile)
-import Debian.Changes (parseChangeLog)
+import Debian.Changes (ChangeLog, parseChangeLog)
 import Debian.Control (Control'(unControl), ControlFunctions, Field, Field'(..), Paragraph'(..), parseControlFromFile, stripWS)
 import Debian.Debianize.DebInfo (changelog, compat, control, copyright, install, installDir, installInit, intermediateFiles, link, logrotateStanza, postInst, postRm, preInst, preRm, rulesHead, sourceFormat, warning, watch)
 import qualified Debian.Debianize.DebInfo as T (flags, makeDebInfo)
@@ -35,13 +36,13 @@ import qualified Debian.Debianize.SourceDebDescription as S (binaryPackages, bui
 import Debian.Orphans ()
 import Debian.Policy (parseMaintainer, parsePackageArchitectures, parseStandardsVersion, parseUploaders, readPriority, readSection, readMultiArch, readSourceFormat, Section(..))
 import Debian.Relation (BinPkgName(..), parseRelations, Relations, SrcPkgName(..))
-import Debug.Trace (trace)
+--import Debug.Trace (trace)
 import Distribution.Package (PackageIdentifier(..), PackageName(..))
 import qualified Distribution.PackageDescription as Cabal (dataDir, PackageDescription(package))
 import Prelude hiding (break, lines, log, null, readFile, sum, words)
 import System.Directory (doesFileExist)
 import System.FilePath ((</>), dropExtension, takeExtension)
-import System.IO.Error (catchIOError, tryIOError)
+import System.IO.Error (catchIOError, isDoesNotExistError, tryIOError)
 -- import System.Unix.Chroot (useEnv)
 -- import Text.ParserCombinators.Parsec.Rfc2822 (NameAddr)
 
@@ -171,14 +172,36 @@ yes "yes" = True
 yes "no" = False
 yes x = error $ "Expecting yes or no: " ++ x
 
+-- | Look in several places for a debian changelog
 inputChangeLog :: MonadIO m => DebianT m ()
 inputChangeLog =
-    do log <- liftIO $ tryIOError (readFile "debian/changelog" >>= return . parseChangeLog . unpack)
-       changelog .?= either (\ _ -> Nothing) Just log
+    do log <- liftIO loadChangeLog
+       changelog .?= log
+
+-- | Look in several places for a debian changelog
+loadChangeLog :: IO (Maybe ChangeLog)
+loadChangeLog =
+    doPaths ["CHANGELOG", "ChangeLog", "changelog", "debian/changelog"]
+    where
+      doPaths :: [FilePath] -> IO (Maybe ChangeLog)
+      doPaths (p : ps) = doPath p >>= maybe (doPaths ps) (\log -> putStrLn ("Found valid changelog at " ++ p) >> return (Just log))
+      doPaths [] = pure Nothing
+      doPath :: FilePath -> IO (Maybe ChangeLog)
+      doPath p = do
+        t <- tryIOError (readFile p)
+        either doExn doParse t
+          where
+            doParse :: Text -> IO (Maybe ChangeLog)
+            doParse t = do
+              pure $ either (const Nothing) Just (parseChangeLog (unpack t))
+            doExn :: IOError -> IO (Maybe ChangeLog)
+            doExn e | isDoesNotExistError e = pure Nothing
+            doExn e = error ("inputChangelog: " ++ show e)
 
 inputCabalInfoFromDirectory :: MonadIO m => DebianT m () -- .install files, .init files, etc.
 inputCabalInfoFromDirectory =
-    do findFiles
+    do findChangeLog -- Look for changelog in unconventional locations
+       findFiles     -- If debian/changelog is found it will replace what we found above
        doFiles ("./debian/cabalInstall")
     where
       -- Find regular files in the debian/ or in debian/source/format/ and
@@ -189,6 +212,10 @@ inputCabalInfoFromDirectory =
           return . (++ ["source/format"]) >>=
           liftIO . filterM (doesFileExist . (("debian") </>)) >>= \ names ->
           mapM_ (inputCabalInfo ("debian")) names
+      findChangeLog :: MonadIO m => DebianT m ()
+      findChangeLog =
+          filterM (liftIO . doesFileExist) ["changelog", "ChangeLog", "CHANGELOG"] >>= \names ->
+          mapM_ (inputCabalInfo ".") names
       doFiles :: MonadIO m => FilePath -> DebianT m ()
       doFiles tmp =
           do sums <- liftIO $ getDirectoryContents' tmp `catchIOError` (\ _ -> return [])
@@ -208,8 +235,13 @@ inputCabalInfo debian name@"watch" = liftIO (readFile (debian </> name)) >>= \ t
 inputCabalInfo debian name@"rules" = liftIO (readFile (debian </> name)) >>= \ text -> rulesHead .= (Just $ strip text <> pack "\n")
 inputCabalInfo debian name@"compat" = liftIO (readFile (debian </> name)) >>= \ text -> compat .= Just (read' (\ s -> error $ "compat: " ++ show s) (unpack text))
 inputCabalInfo debian name@"copyright" = liftIO (readFile (debian </> name)) >>= \ text -> copyright .= Just (readCopyrightDescription text)
-inputCabalInfo debian name@"changelog" =
-    liftIO (readFile (debian </> name)) >>= return . parseChangeLog . unpack >>= \ log -> changelog .= Just log
+-- The normal position for a debian changelog is debian/changelog, but
+-- we also look for it in changelog, ChangeLog, and CHANGELOG because
+-- hackage looks for it in those places and the debianization is
+-- better off with those entries than without.
+inputCabalInfo debian name@"changelog" = do
+  log <- liftIO (readFile (debian </> name)) >>= return . either (const Nothing) Just . parseChangeLog . unpack
+  changelog .= log
 inputCabalInfo debian name =
     case (BinPkgName (dropExtension name), takeExtension name) of
       (p, ".install") ->   liftIO (readFile (debian </> name)) >>= \ text -> mapM_ (readInstall p) (lines text)
